import pytest
from emojificate.filter import emojificate

TEST_NOCHANGE = [
    "☆*:.｡. (づ ◕‿◕ )づ .｡.:*☆",
    "This is a test of the emojification system!",
]


def test_nochange():
    for phrase in TEST_NOCHANGE:
        parsed = emojificate(phrase)
        assert phrase == parsed



import pytest
from emojificate.filter import emojificate


def valid(emoji, title, fuzzy=False):
    parsed = emojificate(emoji)

    assert emoji in parsed
    assert 'alt="{}'.format(emoji) in parsed

    assert title in parsed
    if not fuzzy:
        assert 'aria-label="Emoji: {}'.format(title) in parsed


def test_flag():
    valid("🇦🇺", "Australia", fuzzy=True)


def test_pride():
    valid("🏳️‍🌈", "Rainbow Flag")


def test_farmer():
    valid("👩🏼‍🌾", "Woman Farmer Medium-Light Skin Tone")



import unicodedata
from grapheme import graphemes
import emoji
import requests


__all__ = ["emojificate"]

cdn_fmt = "https://twemoji.maxcdn.com/v/latest/72x72/{codepoint}.png"


def valid_src(src):
    req = requests.head(src)
    return req.status_code == 200


def valid_category(char):
    try:
        return unicodedata.category(char) == "So"
    except TypeError:
        return False


def get_best_name(char):
    """
    unicode data does not recognise the grapheme, 
    so try and parse something from emoji instead.
    """
    shortcode = emoji.demojize(char, use_aliases=True)

    # Roughly convert shortcode to screenreader-friendly sentence.
    return shortcode.replace(":", "").replace("_", " ").replace("selector", "").title()


def convert(char):
    def tag(a, b):
        return '%s="%s"' % (a, b)

    def codepoint(codes):
        # See https://github.com/twitter/twemoji/issues/419#issuecomment-637360325
        if "200d" not in codes:
            return "-".join([c for c in codes if c != "fe0f"])
        return "-".join(codes)

    if valid_category(char):
        # Is a Char, and a Symbol
        name = unicodedata.name(char).title()
    else:
        if len(char) == 1:
            # Is a Char, not a Symbol, we don't care.
            return char
        else:
            # Is probably a grapheme
            name = get_best_name(char)

    src = cdn_fmt.format(codepoint=codepoint(["{cp:x}".format(cp=ord(c)) for c in char]))

    # If twitter doesn't have an image for it, pretend it's not an emoji.
    if valid_src(src):
        return "".join(
            [
                "<img",
                tag(" src", src),
                tag(" alt", char),
                tag(" title", name),
                tag(" aria-label", "Emoji: %s" % name),
                ">",
            ]
        )
    else:
        return char


def emojificate(string):
    return "".join(convert(ch) for ch in graphemes(string))



import re
from setuptools import setup, find_packages
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the relevant file
with open(path.join(here, "README.rst"), encoding="utf-8") as f:
    long_description = f.read()

with open(
    path.join(here, "emojificate", "__init__.py"), encoding="utf8"
) as version_file:
    version_match = re.search(
        r"^__version__ = ['\"]([^'\"]*)['\"]", version_file.read(), re.M
    )
    if version_match:
        version = version_match.group(1)
    else:
        raise RuntimeError("Unable to find version string.")

setup(
    name="emojificate",
    version=version,
    description="A Python implementation of a concept of using fallback images, alt text, title text and aria labels to represent emoji in HTML code in a more accessible method.",
    long_description=long_description,
    url="https://github.com/glasnt/emojificate",
    author="Katie McLaughlin",
    author_email="katie@glasnt.com",
    license="New BSD",
    install_requires=["emoji", "grapheme", "requests"],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Topic :: Text Processing :: Filters",
        "Topic :: Utilities",
    ],
    keywords="emoji accessibility a11y",
    packages=find_packages(exclude=["docs", "test"]),
)



import pytest
import sys, os

sys.path.append(os.path.dirname(os.path.abspath(__file__)))
from emojificate.filter import emojificate

# A list of new emoji introduced in the unicodedata set for that version of Python
# Emoji introduced in later versions won't be available in earlier ones.
PYTHON_35 = {"alt": "🙃", "title": "Upside-Down Face"}
PYTHON_36 = {"alt": "🤣", "title": "Rolling On The Floor Laughing"}
PYTHON_37 = {"alt": "🥰", "title": "Smiling Face With Smiling Eyes And Three Hearts"}
PYTHON_38 = {"alt": "🤩", "title": "Grinning Face With Star Eyes"}


def valid(data):
    alt = data["alt"]
    title = data["title"]
    parsed = emojificate(alt)
    assert alt in parsed
    assert 'alt="{}'.format(alt) in parsed

    assert title in parsed
    assert 'aria-label="Emoji: {}'.format(title) in parsed


@pytest.mark.skipif(sys.version_info.minor < 5, reason="requires Python 3.5 or higher")
def test_python_35_char():
    valid(PYTHON_35)


@pytest.mark.skipif(sys.version_info.minor < 6, reason="requires Python 3.6 or higher")
def test_python_36_char():
    valid(PYTHON_36)


@pytest.mark.skipif(sys.version_info.minor < 7, reason="requires Python 3.7 or higher")
def test_python_37_char():
    valid(PYTHON_37)


@pytest.mark.skipif(sys.version_info.minor < 8, reason="requires Python 3.8 or higher")
def test_python_38_char():
    valid(PYTHON_38)
